@@ -368,7 +368,6 @@ class ReporteBase(ApiCammesa):
                     .pipe(lambda adf: adf.loc[:,['Fecha'] + adf.iloc[:,0:-1].columns.to_list()])
                 )
 
-
     def __procesar_archivos(self):
         '''Abre y filtra todos los archivos disponibles MDB para los parques seleccionados.
         Devuelve un df de pandas unificado.
@@ -459,15 +458,10 @@ class ReporteBase(ApiCammesa):
         
         if self._datos is None:
             self.cargar(descargar=descargar,filtro=filtro,exportar_consulta=exportar_consulta)
-            
-        df = self._datos
         
-        if not df.empty:
-            fecha_desde_real = df.loc[:,"Fecha"].min().strftime('%y-%m-%d')
-            fecha_hasta_real = df.loc[:,"Fecha"].max().strftime('%y-%m-%d')
-
-            # Al convertir la fecha a dt.date, no se puede ejecutar el script dos veces
-            df.loc[:,"Fecha"] = df.loc[:,"Fecha"].dt.date
+        if not self._datos.empty:
+            fecha_desde_real = self._datos.loc[:,"Fecha"].min().strftime('%y-%m-%d')
+            fecha_hasta_real = self._datos.loc[:,"Fecha"].max().strftime('%y-%m-%d')
 
             prefijo = f'{self.nombre} {self.tabla_datos}'
             rango_fechas = f'{fecha_desde_real} a {fecha_hasta_real}'
@@ -482,7 +476,8 @@ class ReporteBase(ApiCammesa):
             else:
                 ruta_salida = self.dir_salida + '\\' + nombre_archivo
 
-            df.to_excel(ruta_salida, index=False,engine='openpyxl')
-            
-            # Con esta línea, los datos se vuelven a convertir en formato dt.datetime y el script se puede correr varias veces.
-            df.loc[:,"Fecha"] = pd.to_datetime(df.loc[:,"Fecha"],format='%Y-%m-%d')
\ No newline at end of file
+            # Exportar
+            (self._datos
+             .assign(Fecha = lambda adf: adf.Fecha.dt.date)
+             .to_excel(ruta_salida, index=False,engine='openpyxl')
+            )
\ No newline at end of file
