@@ -158,6 +158,12 @@ class TablasVC(SQLConnector):
     def solo_CROM(self,val):
         if isinstance(val,bool):
             self._solo_CROM = val
+            try:
+                self.__consultar_ucs(solo_CROM=val)
+                self.__consultar_nemoCammesa(solo_CROM=val)
+            except:
+                pass
+            
         else:
             raise TypeError('solo_CROM puede tomar sólo valores booleanos: True/False')
 
@@ -228,7 +234,7 @@ class TablasVC(SQLConnector):
             return ('Nemo',nemo_parque)
         else:
             uc = self.__check_uc(uc)
-            return ('UC',nemo_parque)
+            return ('UC',uc)
 
     def __check_filtro(self,filtro):
         if not isinstance(filtro,str):
@@ -358,6 +364,41 @@ class TablasVC(SQLConnector):
         fecha_cod = self.__obtener_cod(filtro,valor)
         return fechas.año_op(fecha_cod=fecha_cod,fecha_actual=fecha)
 
+    def __consultar_idsApiCammesa(self):
+
+        self.idsApiCammesa =  (self.central
+            .query('idApiCammesa > 0')
+            [['unidadComercial','idApiCammesa']]
+            .set_index('unidadComercial')
+            .to_dict('dict')
+            ['idApiCammesa']
+        )  
+
+    def __consultar_ucs(self,solo_CROM=False):
+        if solo_CROM:
+            self.ucs = (self.central
+                .query('opcCROM.notna()')
+                ['unidadComercial']
+                .to_list()
+            )
+        else:
+            self.ucs = self.central['unidadComercial'].to_list()
+
+    def __consultar_nemoCammesa(self,solo_CROM=False):
+
+        if solo_CROM:
+            self.nemos = (self.central
+                .query('nemoCammesa.str.len() >0 & opcCROM.notna()')
+                ['nemoCammesa']
+                .to_list()
+            )
+        else:
+            self.nemos = (self.central
+                .query('nemoCammesa.str.len() >0')
+                ['nemoCammesa']
+                .to_list()
+            )
+
     #
     # Procesamiento de incidencias
     #
@@ -778,9 +819,9 @@ class TablasVC(SQLConnector):
         self.__consultar(tablas,mensajes=mensajes,desconectar=False)
 
         if self.checkear_conexion(mensajes=mensajes):
-            self.consultar_idsApiCammesa()
-            self.consultar_ucs(solo_CROM=self.solo_CROM)
-            self.consultar_nemoCammesa(solo_CROM=self.solo_CROM)
+            self.__consultar_idsApiCammesa()
+            self.__consultar_ucs(solo_CROM=self.solo_CROM)
+            self.__consultar_nemoCammesa(solo_CROM=self.solo_CROM)
         
         self._crear_dict_tipo_empresa()
         
@@ -884,9 +925,9 @@ class TablasVC(SQLConnector):
                 except:
                     pass
                 
-                self.consultar_idsApiCammesa()
-                self.consultar_ucs(solo_CROM=self.solo_CROM)
-                self.consultar_nemoCammesa(solo_CROM=self.solo_CROM)
+                self.__consultar_idsApiCammesa()
+                self.__consultar_ucs(solo_CROM=self.solo_CROM)
+                self.__consultar_nemoCammesa(solo_CROM=self.solo_CROM)
                 
                 self._crear_dict_tipo_empresa()
             else:
@@ -905,32 +946,6 @@ class TablasVC(SQLConnector):
     #
     # Funciones visibles al usuario, de consulta de datos
     #
-    def consultar_idsApiCammesa(self):
-        flt = self.central['idApiCammesa'] > 0
-        self.idsApiCammesa =  self.central\
-                                    .loc[flt,['unidadComercial','idApiCammesa']]\
-                                    .set_index('unidadComercial')\
-                                    .to_dict('dict')['idApiCammesa']  
-
-    def consultar_ucs(self,solo_CROM=False):
-        if solo_CROM:
-            flt_sc = self.central['opcCROM'].isna()
-            self.ucs = self.central.loc[~flt_sc,'unidadComercial'].to_list()
-        else:
-            self.ucs = self.central.loc[:,'unidadComercial'].to_list()
-
-    def consultar_nemoCammesa(self,solo_CROM=False):
-        flt = self.central['nemoCammesa'].str.len() > 0     
-        
-        if solo_CROM:
-            flt_sc = self.central['opcCROM'].isna()
-            self.nemos = self.central\
-                    .loc[flt & ~flt_sc,'nemoCammesa']\
-                    .to_list()
-        else:
-            self.nemos = self.central\
-                                .loc[flt,'nemoCammesa']\
-                                .to_list()
 
     def consultar_equipos(self,nemo_parque='',uc='',potencia=False):
         filtro,valor = self.__check_params_nemo_uc(nemo_parque,uc)
@@ -964,7 +979,7 @@ class TablasVC(SQLConnector):
                   datos_basicos=False,
                   incidencias=False,
                   fecha_i=fechas.restar_mes(fechas.mes_ant_dia_1()),
-                  fecha_f=fechas.ayer().replace(hour=23,minute=59,second=59),
+                  fecha_f=fechas.ayer().replace(hour=23,minute=59,second=59,microsecond=9999),
                   mensajes=False
                   ):
 
