@@ -148,4 +148,10 @@ def crear_bins_viento_dir(rosa=None):
     return bins, labels
 
 def interpolar_ppos(df_curva,wind):
-    return __np.interp(wind,df_curva['WS'],df_curva.iloc[:,-1],left=0,right=0)
+    return __np.interp(
+        x = wind,
+        xp = df_curva['WS'],
+        fp = df_curva.iloc[:,-1],
+        left = 0,
+        right = 0
+    )
